@@ -1,5 +1,5 @@
 from django.conf.urls import url
-from NEMO.apps.NEMO_transaction_validation import views
+from NEMO_transaction_validation import views
 
 urlpatterns = [
 	# Add your urls here.
